referrerpolicy=no-referrer-when-downgrade

Config

Trait Config 

pub trait Config:
    Config
    + Config<RuntimeEvent: From<Event<Self>>>
    + Config<RuntimeEvent: From<Event<Self>>> {
    type Sender: SendValidatorSet<Self::AccountId>;
    type Destinations: Get<Vec<DestinationOf<Self>>>;
    type WeightInfo: WeightInfo;
}
Configuration trait of this pallet.

The main purpose of this trait is to act as an interface between this pallet and the runtime in which it is embedded in. A type, function, or constant in this trait is essentially left to be configured by the runtime that includes this pallet.

Consequently, a runtime that wants to include this pallet must implement this trait. Configuration trait of this pallet.

Required Associated Types

type Sender: SendValidatorSet<Self::AccountId>

Sends an announced set to one destination.

type Destinations: Get<Vec<DestinationOf<Self>>>

The other system chains every announced set is sent to. This chain is served through the receiver directly.

Every send is charged the weight measured for the first entry, so no entry may cost more to send than it.

type WeightInfo: WeightInfo

Weight information for this pallet.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors